Learn R Programming

abcdeFBA (version 0.2)

CHANGE_RXN_BOUNDS: CHANGE_RXN_BOUNDS, Change Reaction Bounds

Description

this function helps to modify the bounds on the fba_object, it returns an object of the same type as the model, inspired by the COBRA-function of the same name

Usage

CHANGE_RXN_BOUNDS(reaction_number,fba_object,lower_bound,upper_bound)

Arguments

fba_object
Is a list containing the data required to perform flux balance analysis. The elements of the list are mat which is the stoichiometric matrix, dir which gives the direction of the equality constraints, obj specifies the objective function for the simu
lower_bound
the new value of the lower bound
upper_bound
the new value of the upper bound
reaction_number
the reaction number of the reaction the bounds of which have to be changed

Examples

Run this code
#Changing Reaction Bounds, to simulate the deletion/inhibition of a reaction.
	data(Ecoli_core)	
	Ec_mutant<-CHANGE_RXN_BOUNDS(reaction_number=36,fba_object=Ecoli_core,
	lower_bound=0,upper_bound=0)

Run the code above in your browser using DataLab