fba_object
Is a list containing the data required to perform flux
balance analysis. The elements of the list are mat which is the
stoichiometric matrix, dir which gives the direction of the equality
constraints, obj specifies the objective function for the simulation,
bounds specifies the lower and upper inequality constraints, rhs is the
right hand side of the steady state expression, types refers to the
numeric nature of the variables which in case of FBA happens to be
"Continuous", max is a Boolean specifying the type of optimization,
"Maximization" by default, all_genes is all the genes present in the
model, gpr contains boolean expressions of gene essentiality for the
corresponding reactions in the model, metabolite_name contains list of
all the metabolites, reaction_list contains all the reactions present in
the model, compartment is a numeric identifier for each reaction the key
for which is in comp_name.
thread_no
This specifies the thread number, it is useful to
think of the thread number as a chunk of the complete combination of
all pairs of reactions that can be formed. This depends on the number of
the cores you are employing which must obviously be a fixed number.
For instance if you have a 40 core computer you can divide the double-knockout
simulation into 40 chunks. In that case the thread number would refer to
the chunks of simulation as 0-39, with thread 0 performing the first 1/40th
part of the simulation