Learn R Programming

abcdeFBA (version 0.2)

FLUX_VAR_ANALYSIS: FLUX_VAR_ANALYSIS, a function to perform a flux variability analysis.

Description

FVA can indicate the decrease in network robustness caused by non-lethal deletions.

Usage

FLUX_VAR_ANALYSIS(fba_object,reactions,filename)

Arguments

fba_object
Is a list containing the data required to perform flux balance analysis. The elements of the list are mat which is the stoichiometric matrix, dir which gives the direction of the equality constraints, obj specifies the objective function for the simu
reactions
subset of reaction numbers on which to perform FVA, if left empty, all reactions of the network will be subject to FVA
filename
A string which will be the name of the file containing the output of the FVA simulation

Examples

Run this code
#Simple flux variability Analysis
	data(Ecoli_core)
	FLUX_VAR_ANALYSIS(Ecoli_core, filename="Wt_FVA.xls")

Run the code above in your browser using DataLab