H_sapien_Recon1: H. sapien Recon1, human metabolic network reconstruction
Description
This "list" form of the human model Recon1 was created
from the S4 object created by readSBMLmod from the package Sybil
using the Sybil_2_FBA_obj function.Format
A list containing the information required to perform FBA and
annotations for intelligible output.Source
BiGG databaseReferences
Duarte NC, Becker SA, Jamshidi N, Thiele I, Mo ML, Vo TD, Srivas R
and Palsson BO, Global reconstruction of the human metabolic network based on
genomic and bibliomic data, PNAS.