M_tb_iNJ661: M. tuberculosis model iNJ661
Description
This "list" form of the M.tb model iNJ661
was created from the S4 object created by readSBMLmod
from the package Sybil using the Sybil_2_FBA_obj function.format
A list containing the information required to perform FBA and annotations for intelligible output.source
BiGG databaseReferences
Bordbar A, Lewis NE, Schellenberger J, Palsson BO, Jamshidi N, Insight into human alveolar macrophage and M. tuberculosis interactions via metabolic reconstructions, Molecular Systems Biology.