this function helps to modify the bounds on the fba_object,
it returns an object of the same type as the model, inspired
by the COBRA-function of the same name
is a list containing the data required to
perform flux balance analysis. The elements of the list are
mat which is the stoichiometric matrix, dir which gives the
direction of the equality constraints, obj specifies the
objective function for the s
lower_bound
the new value of the lower bound
upper_bound
the new value of the upper bound
reaction_number
the reaction number of the reaction the bounds of which have to be changed
#Changing Reaction Bounds, to simulate the deletion/inhibition of a reaction. data(Ecoli_core)
Ec_mutant<-CHANGE_RXN_BOUNDS(reaction_number=36,fba_object=Ecoli_core,
lower_bound=0,upper_bound=0)