Exhaustive_double_deletion: Exhaustive_double_deletion, a function for computing synthetic double knockouts.
Description
Exhaustive_double_deletion enables parallel computing of double knockouts by
splitting and running the simulation as different instances on the same multi-core
machine. The results of the simulation are stored into files named result1,
result2 etc.which may be reassembled using the BFDProcessor function
is a list containing the data required to
perform flux balance analysis. The elements of the list are
mat which is the stoichiometric matrix, dir which gives the
direction of the equality constraints, obj specifies the
objective function for the s
thread_no
This specifies the thread number, it is useful to
think of the thread number as a chunk of the complete combination of
all pairs of reactions that can be formed. This depends on the number of
the cores you are employing which must obviously be a fix
core_number
core_number specifies the number of cores that are available
to you for performing double knockout simulations. It should be a fixed number
for a particular instance of simulations on one model
#Performing double knockouts in a 2 core computer data(Ecoli_core)
Exhaustive_double_deletion(Ecoli_core,0,2)
#New instance of R data(Ecoli_core)
Exhaustive_double_deletion(Ecoli_core,1,2)