Learn R Programming

abcdeFBA (version 0.2)

Exhaustive_single_deletion: Exhaustive_single_deletion, a function that deletes each reaction in the network one at a time and returns results describing reaction lethality

Description

This function takes the argument of type fba_object which would be a FBA object and performs an exhaustive deletion of all the reactions in the reaction network and returns a list of biomass generated for all the deletions, the sub-optimal deletions, the super-optimal deletions and non-lethal deletions, also generates a pdf containing a distribution of the fatal reactions according to their sub-systems and a histogram of the biomass distribution for each deletion.

Usage

Exhaustive_single_deletion(fba_object,reactions,plot_to_file)

Arguments

fba_object
Is a list containing the data required to perform flux balance analysis. The elements of the list are mat which is the stoichiometric matrix, dir which gives the direction of the equality constraints, obj specifies the objective function for the simu
reactions
is a vector containing the reaction numbers to be deleted, if none (default=NULL) are supplied all the reactions in the model are deleted iteratively.
plot_to_file
is a boolean indicating if a PDF output of the results of the single deletion should be made.

Examples

Run this code
#Performing an exhaustive single reaction deletion
	data(Ecoli_core)
	Results<-Exhaustive_single_deletion(Ecoli_core)

Run the code above in your browser using DataLab