fba_object
Is a list containing the data required to perform flux
balance analysis. The elements of the list are mat which is the
stoichiometric matrix, dir which gives the direction of the equality
constraints, obj specifies the objective function for the simu
reactions
subset of reaction numbers on which to perform FVA, if left empty, all
reactions of the network will be subject to FVA