FLUX_VAR_ANALYSIS: FLUX_VAR_ANALYSIS, a function to perform a flux variability analysis.
Description
FVA can indicate the decrease in network robustness caused by non-lethal deletions.
Usage
FLUX_VAR_ANALYSIS(fba_object, filename)
Arguments
fba_object
Is a list containing the data required to perform
flux balance analysis. The elements of the list
are mat which is the stoichiometric matrix, dir which
gives the direction of the equality constraints, obj
specifies the objective function for the s
filename
A string which will be the name of the file containing the
output of the FVA simulation