M_barkeri_iAF629: Genome scale metabolic model for the archaeal methanogen M. Barkeri
Description
This "list" form of the M.Barkeri model
was created from the S4 object created by readSBMLmod
from the package Sybil using the Sybil_2_FBA_obj function.Usage
M_barkeri_iAF629.rda
format
A list containing the information required to perform FBA and annotations for intelligible output.source
BiGG databaseReferences
Modeling methanogenesis with a genome scale metabolic reconstruction of Methanosarcina barkeri
by Feist AM, Scholten JCM, Palsson BO